@@ -7,7 +7,7 @@ testthat::test_that(
 
 		testthat::skip_on_cran()
 
-		bundles <- fhir_search( request = "https://hapi.fhir.org/baseR4/Patient?_pretty=true", max_bundles = 5 )
+		bundles <- fhir_search( request = "https://server.fire.ly/Patient?", max_bundles = 2 )
 
 		testthat::expect_false( is.null( bundles ) )
 		testthat::expect_true( is.list( bundles ) )
@@ -20,7 +20,7 @@ testthat::test_that(
 #########################################################################################################
 testthat::context( "fhir_save" )
 
-directory <- tempdir()
+directory <- paste0(tempdir(), "/bundles")
 
 fhir_save( fhir_unserialize(patient_bundles), directory)
 
@@ -34,7 +34,7 @@ testthat::test_that(
 #########################################################################################################
 testthat::context( "fhir_load()" )
 
-myBundles <- fhir_load( directory )
+myBundles <- fhir_load(directory =  directory )
 
 testthat::test_that(
 	"fhir_load reads all bundles as xml files from the given directory", {
@@ -56,7 +56,7 @@ testthat::test_that(
 
 		testthat::skip_on_cran()
 
-		caps <- fhir_capability_statement("https://hapi.fhir.org/baseR4", sep = " ~ ")
+		caps <- fhir_capability_statement(url = "https://server.fire.ly", sep = " ~ ")
 
 		testthat::expect_false( is.null( caps ) )
 		testthat::expect_true( is.list( caps ) )
@@ -69,36 +69,27 @@ testthat::test_that(
 #########################################################################################################
 testthat::context( "fhir_crack()" )
 
-xmlfile <- xml2::read_xml( "specimen.xml" )
+bundles <- fhir_unserialize(bundles = patient_bundles)
 
-design <- list(
-
-	Specimen = list(
-		resource = "//extension[@url='https://fhir.bbmri.de/StructureDefinition/StorageTemperature']",
-		cols = list(
-			VCS  = "valueCodeableConcept/coding/system/@value",
-			CODE = "valueCodeableConcept/coding/code/@value"
-		)
-	)
+design <- fhir_design(
+	Patient = fhir_table_description(resource = "Patient")
 )
 
-df <- fhir_crack(bundles = list(xmlfile), design)
+df <- fhir_crack(bundles = bundles, design = design)
 
 testthat::test_that(
 	"crack creates a valid data frame", {
 		testthat::expect_false( is.null( df ) )
-		testthat::expect_false( is.null( df$Specimen ) )
-		testthat::expect_true( is.data.frame( df$Specimen ) )
-		testthat::expect_equal( nrow( df$Specimen ), 1 )
-		testthat::expect_equal( df$Specimen$VCS[ 1 ],  "https://fhir.bbmri.de/CodeSystem/StorageTemperature" )
-		testthat::expect_equal( df$Specimen$CODE[ 1 ], "temperature2to10" )
+		testthat::expect_false( is.null( df$Patient ) )
+		testthat::expect_true( is.data.frame( df$Patient ) )
+		testthat::expect_equal( nrow( df$Patient), 40 )
 	}
 )
 
-design <- list(
+design <- fhir_design(
 
-	Pat = list(
-		resource = ".//Patient",
+	Pat = fhir_table_description(
+		resource = "Patient",
 		cols = list(
 			name = "name/family/@value"
 		)
